
# q-expansion of newform 1089.6.a.e, downloaded from the LMFDB on 23 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K.gens()[0]**i for i in range(len(poly_data))]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1089
weight = 6
poly_data = [0, 1]

# The basis for the coefficient ring is just the power basis
# in the root of the defining polynomial above.
hecke_ring_character_values = None
aps_data = [[0], [0], [-57], [0], [0], [0], [0], [0], [-981], [0], [-7775], [1267], [0], [0], [-24708], [-34806], [24825], [0], [-72917], [66273], [0], [0], [0], [91089], [-163183], [0], [-180244], [0], [0], [-192381], [0], [0], [263283], [0], [0], [0], [280117], [164144], [0], [0], [840189], [279875], [272325], [0], [0], [799900], [0], [-247531], [0], [-1171025], [0], [0], [0], [-1848123], [-339858], [0], [1160850], [0], [0], [0], [0], [0], [0], [3365052], [1048819], [-3282633], [736925], [0], [0], [0], [4379769], [0], [-1313167], [0], [1888625], [-5232669], [5544075], [1560242], [5714850], [0], [-68664], [6857050], [0], [-5105131], [0], [-4177131], [3634761], [0], [0], [7109819], [3208533], [0], [4400233], [0], [-7479800], [0], [10908225], [12325575], [0], [0], [0], [0], [0], [0], [0], [-8053967], [12913008], [0], [-14684364], [0], [0], [0], [-17925558], [-1912711], [12870277], [-15079275], [-20967769], [7186617], [-20654031], [0], [21510073], [0], [0], [-16732344], [25031327], [0], [25915639], [30039], [-17087783], [0], [0], [0], [-25609373], [19576042], [0], [0], [-11899494], [0], [9420783], [0], [0], [0], [35704781], [0], [19068689], [-39359025], [0], [0], [-15048361], [-6796044], [0], [-7122777], [6299944], [0], [30616808], [42696300], [0], [-28341150], [0], [0], [19606233], [0], [0], [-45744525], [47058867], [60550719], [-61768100], [0], [0], [42544269], [0], [-65014750], [0], [0], [-20886589], [65587575], [0], [-20539323], [0], [0], [63320908], [0], [55050481], [0], [-80753631], [-35706486], [0], [-5364544], [0], [0], [-58479419], [0], [56297023], [-92980098], [0], [95496069], [0], [-7350781], [0], [0], [0], [0], [106661942], [0], [42920139], [116007483], [-64287925], [0], [0], [22616200], [0], [-27404775], [119081569], [-110711592], [0], [102701227], [0], [0], [100559292], [-50599419], [0], [0], [145417875], [140598119], [0], [0], [114622506], [-155303700], [0], [0], [-139434931], [0], [0], [0], [68933119], [0], [160071661], [0], [7121475], [146495325], [-137327181], [0], [53548156], [-181554239], [0], [0], [-83032508], [108450648], [0], [0], [0], [0], [150335733], [121499050], [0], [0], [179640650], [0], [215012367], [0], [0], [0], [0], [0], [-16273842], [-82000400], [128496861], [44195523], [0], [0], [252604673], [211064933], [-257318906], [0], [0], [-62646131], [235822167], [0], [0], [0], [0], [239577175], [0], [0], [0], [-260853375], [-273735394], [0], [304966939], [0], [315125127], [73105008], [0], [0], [0], [0], [-332452877], [-179325819], [0], [0], [0], [0], [0], [-350956344], [-99849275], [138947767], [-97578417], [-43587575], [114339036], [0], [0], [-289737450], [0], [144125731], [0], [0], [-326802489], [0], [204505006], [0], [0], [-401610383], [0], [-186808169], [0], [-424677625], [-419127311], [21496081], [0], [0], [0], [-387033858], [0], [0], [0], [32773233], [-282112675], [0], [430853975], [0], [7048769], [172280733], [0], [491727425], [236485269], [0], [-479409577], [-493986667], [0], [359628333], [0], [-480534217], [-553239150], [0], [0], [0], [-529143375], [0], [0], [-508334631], [0], [0], [180728667], [0], [474798733], [450256369], [0], [0], [0], [-83773527], [-464771536], [0], [0], [0], [-438456467], [62348064], [0], [0], [0], [0], [-652669602], [-701897319], [0], [0], [0], [309473019], [722835148], [-657249283], [0], [722092083], [601462589], [-705682419], [501558825], [-345025283], [81851427], [0], [0], [690956550], [779445152], [0], [0], [-672402381], [0], [238916742], [0], [0], [-289989742], [0], [-487100744], [688142475], [0], [0], [543123744], [0], [0], [-592379625], [0], [801123017], [-672747858], [0], [-294645111], [0], [883753308], [0], [-537648406], [-869644767], [-618539781], [0], [689399273], [0]]
